@@ -74,7 +74,7 @@ $FILE = $_;
 $DIR = $DIR . '/' if ($DIR) ;
 $doc_DIR = $doc_DIR . '/' if ($doc_DIR) ; 
 my $LOAD = '\reload{<img src="gifs/doc/etoile.gif" alt="rechargez" width="20" height="20" border=0>}';
-my $FLECHE = '<img src="gifs/arrows/right3.32.gif" alt=" ---> " width="25" height="15" border=0 valign="bottom">';
+my $FLECHE = '<img src="gifs/arrows/right3.32.gif" alt=" ---> " width="25" height="15" border=0>';
 $linkout = "\\doc{module=$linkout}" . $FLECHE if ($linkout) ; 
 
 ##################################
@@ -281,6 +281,7 @@ my @cnt = (0) x ($#SECTIONS + 1);
 my ($secpattern) = join('|', @SECTIONS);
 $TEXT =~ s/\\begin\s*{($secpattern)\s*}/cnt_section($1,\@cnt)/eg;
 $TEXT =~ s/\\end\s*{\s*($secpattern)\s*}/<\/$1>/g;
+$TEXT =~ s/\\wimsentre{($secpattern)}/\\wimsentre$1/g;
 $TEXT =~ s/\\(wimsentre)?($secpattern)\b\*?/open_close($2,\@cnt,$1)/eg;
 $TEXT =~ s|</document>.*||s;
 $TEXT =~ s|.*<document>||s;
@@ -363,8 +364,8 @@ for my $tag (keys %{$hash{text}}) {
   my $CHEMIN = chemin($tag, \%hash);
   #J'ai enlev $LOAD
   $CHEMIN = ($dotoc_up || $dotoc_down)  && ($CHEMIN =~ $FLECHE) ? $CHEMIN : '';
-  my $CHEMIN_up=($dotoc_up) ? $CHEMIN : '' ;
-  my $CHEMIN_down=($dotoc_down) ? $CHEMIN : '' ; 
+  my $CHEMIN_up=($dotoc_up) ? "<div id=\"up_toc\">$CHEMIN</div>": '' ;
+  my $CHEMIN_down=($dotoc_down) ? "<div id=\"down_toc\">$CHEMIN</div>" : '' ; 
   my @Chemin = split(',', $hash{chemin}{$tag});
   my $TOCg = $dotoc_left ? selection($hash{toc}{main}, 'left_selection', @Chemin) : '';
   my $TOCd = ($dotoc_right && $tagupbl ne 'main') ? selection($hash{toc}{$tagupbl}, 'right_selection', @Chemin) : '';
@@ -428,7 +429,7 @@ sub analyse_texte { my ($TEXT, $ref, $Id, $niveau, $niveau_max, $Toc) = @_;
     $ref->{toctip}{$Id} .= $ref->{tittoc}{$id} ;
     $tp = "ZZZZZ$id" ; }
     $ref->{toc}{$Id} .= "\n<XXXX=$id>\\link{$id}{$ref->{tittoc}{$id}
-    $tp }<YYYY=$id>\n";
+    }$tp <YYYY=$id>\n";
   }
  #maintenant, ce qui reste dans $text est exactement ce qu'on doit mettre dans le hash->{text}{$Id}
   $ref->{text}{$Id} = $text;
@@ -530,6 +531,7 @@ for my $rubrique (@liste_env_tabular) {
   if ($TEXT =~ /\\begin\{\s*(\w*)\s*\}/g) {
      warn " ATTENTION : environnement non rpertori : $1" if $1 ne 'matrix';
   }
+  $TEXT =~ s,<li>\n+</li>,<li></li>,g;
   $TEXT;
 }
 
@@ -696,18 +698,18 @@ sub tabular { my ( $b, $style ) = @_;
   my @v = extract_bracketed ($b, '{}') ; 
   my $stylerow = $style . "_row";
   my $stylecell = $style . "_cell";
-  $b =  "<table class=\"$style\"><tr class=\"$stylerow\"><td class=$stylecell>" . $v[1] . '</table>';
-  $b =~ s|\&|&nbsp;</td><td class=$stylecell>&nbsp;|g;
+  $b =  "<table class=\"$style\"><tr class=\"$stylerow\"><td class=\"$stylecell\">" . $v[1] . '</table>';
+  $b =~ s|\&|&nbsp;</td><td class=\"$stylecell\">&nbsp;|g;
   $b =~ s/\\hline//g;
   $b =~ s|\\\\\s*</table>|</td></tr></table>|g;
   my $par="\\\\\\(|\\\\\\)" ;
   my @dectab = split(/$par/, $b) ; 
   $b = $dectab[0] ; 
-  $b =~ s|\\\\|</td></tr><tr class=$stylerow><td class=$stylecell>|g;
+  $b =~ s|\\\\|</td></tr><tr class=\"$stylerow\"><td class=\"$stylecell\">|g;
   my $cnt = 0; $b = '' ; 
   while ($cnt <= $#dectab/2) { 
      my $c = $dectab[2*$cnt] ; 
-     $c =~ s|\\\\|</td></tr><tr class=$stylerow><td class=$stylecell>|g;
+     $c =~ s|\\\\|</td></tr><tr class=\"stylerow\"><td class=\"$stylecell\">|g;
      $b .=  $c . (($dectab[2*$cnt+1]) ? "\\(" . $dectab[2*$cnt+1] .  "\\)" : '' )  ; 
      $cnt ++ ; 
  };
@@ -1096,6 +1098,9 @@ sub traitement_initial { my ($TEXT) = @_;
   $TEXT =~ s/\\'\s*e//g;
   $TEXT =~ s/\\`\s*e//g;
   $TEXT =~ s/\\\^\s*e//g;
+  $TEXT =~ s/\\`\s*E//g;
+  $TEXT =~ s/\\\'\s*E//g;
+  $TEXT =~ s/\\\^\s*E//g;
   $TEXT =~ s/\\\^\s*i//g;
   $TEXT =~ s/\\\`\s*i//g;
   $TEXT =~ s/\\\"\s*i//g;
@@ -1121,6 +1126,12 @@ sub traitement_initial { my ($TEXT) = @_;
   $TEXT =~ s/{\s*\\\^\s*u\s*}//g;
   $TEXT =~ s/{\s*\\`\s*u\s*}//g;
   $TEXT =~ s/{\s*\\c \s*c\s*}//g;
+  $TEXT =~ s/{\\textquotesingle}/'/g;
+  $TEXT =~ s/\\textquotesingle/'/g;
+  $TEXT =~ s/\\guillemotleft/<</g;
+  $TEXT =~ s/\\guillemotright/>>/g;
+  $TEXT =~ s/{}//g;
+  $TEXT =~ s/\\selectlanguage{french}\\sffamily//g;
   
  #$TEXT =~ s/([^\\])\%+/$1/g;
   $TEXT =~ s/([^\\])\%.*/$1/g;
@@ -1135,8 +1146,8 @@ sub traitement_initial { my ($TEXT) = @_;
   $TEXT =~ s/~(:|;|\?|\!)/&nbsp;$1/g;
  #utiliser verb uniquement dans le cas d'un mot
 #FIXME:  $TEXT =~ s/\verb"([^"]+)"/<tt class=verb>$1<\/tt>/g;
-  $TEXT =~ s/\\includegraphics\s*\[(.*)\]\s*{(.*)}/<img src=\\filedir\/$2 $1>/g;
-  $TEXT =~ s/\\includegraphics\s*{(.*)}/<img src=$1>/g;
+  $TEXT =~ s/\\includegraphics\s*\[(.*)\]\s*{(.*)}/<img src=\"\\filedir\/$2\" $1 alt=\"\">/g;
+  $TEXT =~ s/\\includegraphics\s*{(.*)}/<img src=\"$1\" alt=\"\">/g;
   $TEXT =~ s/\\(begin|end){document}/\\document /g;
   $TEXT =~ s/\\exercise{module=([^\&]+)\&([^}]+)}{([^}]+)}/store_sheet($1,$2,$3,$worksheet)/eg ; 
   $TEXT =~ s/\\xspace//g;
@@ -1221,14 +1232,14 @@ sub store_ref { my ($link, $titre, $anchor, $ref_bloc) = @_;
 sub toc_HTML {my ($text, $toc_g, $toc_d, $CHEMIN_up, $CHEMIN_down, $index) = @_ ;
   if (($toc_g) || ($toc_d)) {
     $CHEMIN_up . '<table class="doc_table"><tr>'
-   . (($toc_g) ? '<td valign=top><div class="left_toc"><p>' . $toc_g 
-   . $index . '</div></td>' : '')
+   . (($toc_g) ? '<td class="left_toc" id="left_toc">'. $toc_g 
+   . $index . '</td>' : '')
    . '<td valign="top" align="left" width="100%"><div class="wimsdoc">'
    . $text
    . '</div>' .  $CHEMIN_down . ' </td>'
-   . (($toc_d) ? '<td valign="top" align="right"> <div class="right_toc"><p>'
+   . (($toc_d) ? '<td class="right_toc" id="right_toc">'
    . $toc_d
-   . '</div><center>'
+   . '<center>'
    . $LOAD
    . '</center></td>' : '') 
    . '</tr></table>'  }
@@ -1319,8 +1330,10 @@ sub clean { my ($text, $ref) = @_;
 
 sub store_tip { my ($tag,$ref)=@_ ; 
   my $tip = $ref->{toctip}{$tag} ;
-  $tip =~ s/'/\\'/g if ($tip) ; 
-  $ref->{toctip}{$tag} ?  "<span class=tip><a onmouseover=\"Tip('$tip')\">$tooltip_prompt<\/a><\/span>" : '' ; 
+  my $title=$ref->{tittoc}{$tag} ;
+  $tip =~ s/'/\\\\'/g if ($tip) ; 
+   $title =~ s/'/\\\\'/g if ($title) ; 
+  $ref->{toctip}{$tag} ?  "<a onmouseover=\"Tip('$tip',TITLE,'$title',TITLEBGCOLOR,'',width,'200px')\" onmouseout=\"UnTip()\">$tooltip_prompt<\/a>" : '' ; 
 }
 
 sub chemin { my ($tag, $ref) = @_;
