@@ -77,10 +77,10 @@ char PATH[512];  /* directory settings */
 #else
  char *commonpath="/usr/local/bin:/usr/bin:/usr/games:/bin:/usr/bin/X11:/usr/X11R6/bin:/opt/teTeX/bin";
 #endif
-char *gap_command="gap.sh -T";
+char *gap_command="gap.sh -T -m 64M";
 char *maxima_command="maxima";
-char *mupad_command="/usr/local/lib/mupad/share/bin/mupad";
 char *pari_command="gp -f -q -p 150000";
+char *scilab_command="scilab -nwni";
 
   /* default languages */
 char site_langbuf[]="en fr cn es it nl";
@@ -257,7 +257,6 @@ CONFIG_DATA main_config[]={
       {"mu_publish_site",		0, &mu_publish_site},
       {"mu_site",		0, &mu_site},
       {"mu_zone",		0, &mu_zone},
-      {"mupad_command",		2, &mupad_command},
       {"old_log_files",		1, &OLD_LOG_FILES},
       {"page_bgcolor",		0, &bgcolor},
       {"page_bgimg",		0, &bgimg},
@@ -271,6 +270,7 @@ CONFIG_DATA main_config[]={
       {"ref_button_help_color",		0, &ref_button_help_color},
       {"ref_menucolor",		0, &ref_menucolor},
       {"rlimit_cpu",		1, &rlimit_cpu},
+      {"scilab_command",	2, &scilab_command},
       {"show_author",		0, &show_author},
       {"show_ip",		0, &show_ip},      
       {"show_stat",		0, &show_stat},
@@ -410,7 +410,7 @@ void main_configure(void)
     }
     	/* check priority */
     if(priority[0] && checkhost(priority)>0) ispriority=1;
-    getcwd(cwdbuf,sizeof(cwdbuf)); setvar("httpd_PWD",cwdbuf);
+    (void)getcwd(cwdbuf,sizeof(cwdbuf)); setvar("httpd_PWD",cwdbuf);
     setenv("wims_server_base",cwdbuf,1);
     p=strrchr(cwdbuf,'/');
     if(p!=NULL && strcmp(p,"/public_html")==0) {
@@ -751,7 +751,7 @@ void set_job_ident(void)
 	/* define the variable $wims_html_header */
 void define_html_header(void)
 {
-    char *expir, *sp, *cp, *mp;
+  char *expir, *sp, *cp, *ladirection, *mp;
     char buf[MAX_LINELEN+1],ebuf[128];
     char *nocache="<meta http-equiv=\"Pragma\" content=\"no-cache\">\n\
 <meta http-equiv=\"Cache-Control\" content=\"no-cache\">\n";
@@ -790,6 +790,8 @@ void define_html_header(void)
     }
     css: setvar("wims_CSS","");
     cp=getvar("wims_css");
+    ladirection=getvar("wims_main_dirn");
+    if (strcmp(ladirection,"ltr")==0) ladirection="";
     if(!robot_access && cp!=NULL && *cp!=0 && strstr(cp,"---")==NULL) {
 	char *nbuf;
 	cp=find_word_start(cp);
@@ -802,20 +804,20 @@ void define_html_header(void)
 		 if(th==NULL || *th==0) th=getvar("wims_theme"); st=1;
 		 if(ti==NULL || *ti==0) ti=getvar("wims_theme_icon");
 	    }
-	    else {
+	    else {/* Il faut peut-tre changer l aussi pour direction */
 		nbuf=mkfname(NULL,"html/css/%s/%s.css",lang,cp);
 		th=getvar("wims_theme");
 		ti=getvar("wims_theme_icon");
 	    }
 	    if(strcmp(cp,"-theme-")==0 && strchr(th,'.')==NULL) {
 		  if(th==NULL || *th==0) th="default";
-		  nbuf=mkfname(NULL,"html/themes/%s/css.css",th);
+		  nbuf=mkfname(NULL,"html/themes/%s/css%s.css",th,ladirection);
 	    }
 	    if(readfile(nbuf,tmplbuf,sizeof(tmplbuf))) {
 	    }
 	    else {
 	     th=getvar("wims_theme");
-		 nbuf=mkfname(NULL,"html/themes/%s/css.css",th);
+	     nbuf=mkfname(NULL,"html/themes/%s/css%s.css",th,ladirection);
 		}
 		if(readfile(nbuf,tmplbuf,sizeof(tmplbuf))) {
 	      if (st) {snprintf(buf,sizeof(buf),"<style type=\"text/css\"><!--\n\
