@@ -438,6 +438,15 @@ void determine_font(char *l)
     if(i<charname_no) setvar("wims_main_font",charname[i].font);
 }
 
+void determine_dirn(char *l)
+{
+    int i;
+    
+    if(l==NULL || *l==0) return;
+    for(i=0;i<dirnname_no && memcmp(dirnname[i].name,l,2);i++);
+    if(i<dirnname_no) setvar("wims_main_dirn",dirnname[i].dirn);
+}
+
 void predetermine_language(void)
 {
     char *p;
@@ -468,7 +477,7 @@ void predetermine_language(void)
     for(i=0;i<available_lang_no && memcmp(p,available_lang[i],2)!=0;i++);
     if(i<available_lang_no) {
 	lend:	memmove(lang,p,2); lang[2]=0;
-	lend2:	determine_font(lang);
+	lend2:	determine_font(lang);determine_dirn(lang);
     }
 }
 
@@ -476,6 +485,7 @@ void predetermine_language(void)
 void put_special_page(char *pname)
 {
     determine_font(lang);
+    determine_dirn(lang);
     phtml_put_base(mkfname(NULL,"%s.phtml.%s",pname,lang),0);
     write_logs();free(var_str);
 }
@@ -699,7 +709,7 @@ void parse_query_string(int len, int type)
 	    if(j==ro_lang) {
 		if(strlen(p)!=2) continue;
 		for(i=0;i<available_lang_no && strcmp(available_lang[i],p)!=0;i++);
-		if(i<available_lang_no) {user_lang=1; strcpy(lang,p);}
+		if(i<available_lang_no) {user_lang=1; ovlstrcpy(lang,p);}
 		else continue;
 	    }
 	    /* strip leading and trailing '/'s in module name */
@@ -797,6 +807,7 @@ void special_cmds(void)
 	    }
 	    force_setvar("wims_protocol",protocol);
 	    determine_font(lang);
+	    determine_dirn(lang);
 	    main_phtml_put(intro_file); debug_output();
 	    introend: write_logs();free(var_str);
 	    delete_pid(); exit(0);
@@ -810,6 +821,7 @@ void special_cmds(void)
 		else trap_check(p);
 	    }
 	    determine_font(lang);
+	    determine_dirn(lang);
 	    main_phtml_put(ref_file); goto introend;
 	}
 	case cmd_getins: {
@@ -872,7 +884,7 @@ Content-length: %ld\r\n\r\n",fmt,l);
 		char *p1;
 		char mime[MAX_LINELEN+1];
 		for(p1=c+strlen(c);p1>c && isalpha(*(p1-1)); p1--);
-		strcpy(mime,"application/octet-stream");
+		ovlstrcpy(mime,"application/octet-stream");
 		if(p1>c && *(p1-1)=='.') {
 		    setvar("translator_unknown",mime);
 		    setvar("dictionary","bases/sys/mime");
@@ -929,15 +941,16 @@ int verify_tables(void)
 
 void config_defaults(void)
 {
-    int i, *pi;
-    char **ps;
-    
+    int i;
     for(i=0;i<MAIN_CONFIG_NO;i++) {
-	pi=main_config[i].address; ps=main_config[i].address;
-	if((1&main_config[i].is_integer)==1) 
-	  printf("DF_%s=%d\n",main_config[i].name, *pi);
-	else
-	  printf("DF_%s=%s\n",main_config[i].name,*ps);
+	if((1&main_config[i].is_integer)==1) {
+	    int *pi = (int*)main_config[i].address;
+	    printf("DF_%s=%d\n",main_config[i].name, *pi);
+        }
+	else {
+            char **ps = (char**)main_config[i].address;
+	    printf("DF_%s=%s\n",main_config[i].name,*ps);
+        }
     }
 }
 
@@ -1167,6 +1180,7 @@ int main(int argc, char *argv[], char *envp[])
     access_check(0);
     set_variables();
     determine_font(getvar("module_language"));
+    determine_dirn(getvar("module_language"));
     if(!robot_access && session_prefix[0]!=0 && cmd_type!=cmd_help && !ismhelp)
       lastout_file=creat(mkfname(NULL,"%s/%s",s2_prefix,lastout),
 			 S_IRUSR|S_IWUSR);
